import React from "react";
import Hello from "./components/Hello";

function App() {
  return (
    <div>
      <Hello />
    </div>
  );
}


export default App;